OC.L10N.register(
    "files_versions",
    {
    "Could not revert: %s" : "Klarte ikkje å tilbakestilla: %s",
    "Versions" : "Utgåver",
    "Failed to revert {file} to revision {timestamp}." : "Klarte ikkje å tilbakestilla {file} til utgåva {timestamp}.",
    "Restore" : "Gjenopprett"
},
"nplurals=2; plural=(n != 1);");
